@@ -211,11 +211,11 @@ class Tool:
         else:
             return False
 
-    def post_html(self, url, headers={}, data={}, json={}, proxy={}, cookies={}, timeout=5, debug=False):
+    def post_html(self, url, headers={}, data={}, json={}, params={}, proxy={}, cookies={}, timeout=5, debug=False):
 
         for i in range(5):
             try:
-                res = self.session.post(url, data=data, json=json, headers=headers, timeout=timeout, proxies=proxy, cookies=cookies, verify=False)
+                res = self.session.post(url, data=data, json=json, headers=headers, timeout=timeout, proxies=proxy, params=params, cookies=cookies, verify=False)
                 return res
             except Exception as e:
                 if debug:
